@@ -422,7 +422,7 @@ class PortLogQueueHandler(logging.handlers.QueueHandler):
         
 
 class _AddStackContextFilter(logging.Filter):
-    def __init__(self, trim_amount: int = 5, below_level: int = -1):
+    def __init__(self, trim_amount: int = 5, below_level: int = -1, is_syslog: bool = False):
         """Class to prepaire the "stack"-variable within logrecord
 
         Args:
@@ -431,6 +431,7 @@ class _AddStackContextFilter(logging.Filter):
         """        
         self.trim_amount = trim_amount
         self.below_level = below_level
+        self.is_syslog = is_syslog
         
     def IsLast(self,s):
         Such = '\n    root.log(level, msg, *args, **kwargs)\n'
@@ -438,16 +439,21 @@ class _AddStackContextFilter(logging.Filter):
 
     def filter(self, record):
         import traceback
+        if self.is_syslog:
+            Delim = '\u21B2'
+        else:
+            Delim = '\n'
+
         if record.levelno <= self.below_level:
             wStack = traceback.format_stack()
-            ResStr = '\n'
             ResList = []
             for r in wStack:
                 s = str(r)
                 if self.IsLast(s):
                     break
-                ResList.append(s)
-            record.stack = '\n' + ''.join(ResList[0-self.trim_amount:])
+                ResList.append(s.replace('\n', Delim))
+            
+            record.stack = Delim + ''.join(ResList[0-self.trim_amount:])
         else:
             record.stack = ''
         return True
@@ -647,23 +653,23 @@ def SetupLogging(   *,
                 Verbose:int = 0, 
                 NoDaemon:bool = True, 
                 StdErr:bool = False, 
-                LogFile:str = '', 
+                LogPath:str = '', 
                 LogFileInterval:int = 60*60*24,
                 LogFileCount:int = 14,
                 Quiet:bool = False, 
-                ProcInfo:bool = False, 
-                ProcInfoModLen:int = 15,
-                ProcInfoFuncLen:int = 15,
-                LevelType:int = 2,
-                MultiProc:bool = False,
-                MultiProcLen:int = 15,
-                MultiThread:bool = False,
-                MultiThreadLen:int = 15,
-                StackOnDebug:str = 'NONE',
-                StackDepth:int = 5,
-                DebugIp:str = '127.0.0.1',
-                DebugPort:int = 0,
-                DebugCacheSize:int = 100,
+                LogProcInfo:bool = False, 
+                LogProcInfoModLen:int = 15,
+                LogProcInfoFuncLen:int = 15,
+                LogLevelType:int = 2,
+                LogMultiProc:bool = False,
+                LogMultiProcLen:int = 15,
+                LogMultiThread:bool = False,
+                LogMultiThreadLen:int = 15,
+                LogStackOnDebug:str = 'NONE',
+                LogStackDepth:int = 5,
+                LogDebugIp:str = '127.0.0.1',
+                LogDebugPort:int = 0,
+                LogDebugCacheSize:int = 100,
                 NoReset:bool = False) -> PortLogServer:
     """Creates a defined Log-setting with rich options
 
@@ -686,7 +692,7 @@ Args:
                             If this is set the log goes to StdErr.
                             Ignored if we are a daemon.
 
-    LogFile (str, optional): Log to a Log-file. Defaults to ''.
+    LogPath (str, optional): Log to a Log-file. Defaults to ''.
                             Log to the file which is given as the argument.
                             this file is rotated on a daily base and holded up to 14 files
 
@@ -697,16 +703,16 @@ Args:
 
     Quiet (bool, optional): Output only errors. Defaults to False.
 
-    ProcInfo (bool, optional): Show process and thread. Defaults to False.
+    LogProcInfo (bool, optional): Show process and thread. Defaults to False.
 
-    LevelType (int, optional): Format of LevelInfo. 0=None, 1=Number, 2=Name, 3=Both. 
+    LogLevelType (int, optional): Format of LevelInfo. 0=None, 1=Number, 2=Name, 3=Both. 
                                 Defaults to 2.
 
-    MultiProc (bool, optional): Show process-names. Defaults to False.
+    LogMultiProc (bool, optional): Show process-names. Defaults to False.
 
-    MultiThread (bool, optional): Show thread-names. Defaults to False.
+    LogMultiThread (bool, optional): Show thread-names. Defaults to False.
 
-    StackOnDebug (str, optional): Log-level below or equal a call-stack trace is included.
+    LogStackOnDebug (str, optional): Log-level below or equal a call-stack trace is included.
                                 Defaults to "NONE" => Disabled.
                                 The levels are:
                                     "ERROR"
@@ -720,16 +726,16 @@ Args:
                                 All other values are interpretet as "NONE".
                                 Value is not case-sensitive.
 
-    StackDepth (int, optional): Maximum number of call-stack entries to display. Defaults to 5.
+    LogStackDepth (int, optional): Maximum number of call-stack entries to display. Defaults to 5.
 
-    DebugPort (int, optional): If 0 no debug-server is started. Else the value has to be 
-                                between 1024 and 65535. A log-server is started on 'DebugIp' 
-                                at port 'DebugPort'. 
+    LogDebugPort (int, optional): If 0 no debug-server is started. Else the value has to be 
+                                between 1024 and 65535. A log-server is started on 'LogDebugIp' 
+                                at port 'LogDebugPort'. 
                                 It is possible to connect to this port (e.g with telnet) to 
                                 receive ALL log-messages from this program. ALL means really
                                 all, no mather which loglevel is set. This output also 
                                 includes all possible information about process, thread, 
-                                module and function. The stacktrace ('StackOnDebug') is also
+                                module and function. The stacktrace ('LogStackOnDebug') is also
                                 honored. This output can be really heavy, but can help to debug
                                 already running programs without the need to restart with 
                                 another loglevel.
@@ -741,15 +747,15 @@ Args:
                                 by any means except you call the above mentioned functions.
                                 This port has to be free. Defaults to 0.
                                 
-    DebugIp (str, optional): The IP-address to bind to. This address must exist on the host 
+    LogDebugIp (str, optional): The IP-address to bind to. This address must exist on the host 
                                 this program is running. '0.0.0.0' for 'all IPs' is also 
-                                valid. Only examined if 'DebugPort' > 0. 
+                                valid. Only examined if 'LogDebugPort' > 0. 
                                 Defaults to '127.0.0.1',
                                 
-    DebugCacheSize (int, optional): Only used if 'DebugPort' > 0. This is the number of 
+    LogDebugCacheSize (int, optional): Only used if 'LogDebugPort' > 0. This is the number of 
                                 log-messages cached for use at a new connection to the 
                                 server. So if someone connects to the server he receives the
-                                last 'DebugCacheSize' log messages and after them all new 
+                                last 'LogDebugCacheSize' log messages and after them all new 
                                 messages.
                                 This is like a history. if set to 0 this function is disabled.
                                 Defaults to 100.
@@ -764,13 +770,13 @@ Output format:
         Name of application ----+       |           |          |               |     |       |
             only if not StdErr          |           |          |               |     |       |
         Name of procvess ---------------+           |          |               |     |       |
-            if MultiProc = true                     |          |               |     |       |
+            if LogMultiProc = true                  |          |               |     |       |
         Name of thread if --------------------------+          |               |     |       |
-            MultiThread = true                                 |               |     |       |
+            LogMultiThread = true                              |               |     |       |
         Module, function and linenumber -----------------------+               |     |       |
-            only if ProcInfo = true                                            |     |       |
-        Level-number of message if LevelType = 1 or 3 -------------------------+     |       |
-        Level-name of message if LevelType = 2 or 3 ---------------------------------+       |
+            only if LogProcInfo = true                                         |     |       |
+        Level-number of message if LogLevelType = 1 or 3 ----------------------+     |       |
+        Level-name of message if LogLevelType = 2 or 3 ------------------------------+       |
         The message given to the log-call ---------------------------------------------------+
 
         The minimal log entry for StdErr is:
@@ -813,52 +819,52 @@ Output format:
 
 # Check Port option
     try:
-        DebugPort = int(DebugPort)
+        LogDebugPort = int(LogDebugPort)
     except:
-        raise ValueError(f"SetupLogging 'DebugPort' can't be converted to an integer")
-    if DebugPort < 0:
-        DebugPort = 0
+        raise ValueError(f"SetupLogging 'LogDebugPort' can't be converted to an integer")
+    if LogDebugPort < 0:
+        LogDebugPort = 0
 # Check Len options
     try:
-        ProcInfoModLen = int(ProcInfoModLen)
+        LogProcInfoModLen = int(LogProcInfoModLen)
     except:
-        raise ValueError(f"SetupLogging 'ProcInfoModLen' can't be converted to an integer")
-    if ProcInfoModLen < 0:
-        raise ValueError(f"SetupLogging 'ProcInfoModLen' can't be negative")
+        raise ValueError(f"SetupLogging 'LogProcInfoModLen' can't be converted to an integer")
+    if LogProcInfoModLen < 0:
+        raise ValueError(f"SetupLogging 'LogProcInfoModLen' can't be negative")
 
     try:
-        ProcInfoFuncLen = int(ProcInfoFuncLen)
+        LogProcInfoFuncLen = int(LogProcInfoFuncLen)
     except:
-        raise ValueError(f"SetupLogging 'ProcInfoFuncLen' can't be converted to an integer")
-    if ProcInfoModLen < 0:
-        raise ValueError(f"SetupLogging 'ProcInfoFuncLen' can't be negative")
+        raise ValueError(f"SetupLogging 'LogProcInfoFuncLen' can't be converted to an integer")
+    if LogProcInfoFuncLen < 0:
+        raise ValueError(f"SetupLogging 'LogProcInfoFuncLen' can't be negative")
 
     try:
-        MultiProcLen = int(MultiProcLen)
+        LogMultiProcLen = int(LogMultiProcLen)
     except:
-        raise ValueError(f"SetupLogging 'MultiProcLen' can't be converted to an integer")
-    if ProcInfoModLen < 0:
-        raise ValueError(f"SetupLogging 'MultiProcLen' can't be negative")
+        raise ValueError(f"SetupLogging 'LogMultiProcLen' can't be converted to an integer")
+    if LogProcInfoModLen < 0:
+        raise ValueError(f"SetupLogging 'LogMultiProcLen' can't be negative")
 
     try:
-        MultiThreadLen = int(MultiThreadLen)
+        LogMultiThreadLen = int(LogMultiThreadLen)
     except:
-        raise ValueError(f"SetupLogging 'MultiThreadLen' can't be converted to an integer")
-    if ProcInfoModLen < 0:
-        raise ValueError(f"SetupLogging 'MultiThreadLen' can't be negative")
+        raise ValueError(f"SetupLogging 'LogMultiThreadLen' can't be converted to an integer")
+    if LogProcInfoModLen < 0:
+        raise ValueError(f"SetupLogging 'LogMultiThreadLen' can't be negative")
 
     try:
-        DebugCacheSize = int(DebugCacheSize)
+        LogDebugCacheSize = int(LogDebugCacheSize)
     except:
-        raise ValueError(f"SetupLogging 'DebugCacheSize' can't be converted to an integer")
-    if ProcInfoModLen < 0:
-        raise ValueError(f"SetupLogging 'DebugCacheSize' can't be negative")
+        raise ValueError(f"SetupLogging 'LogDebugCacheSize' can't be converted to an integer")
+    if LogProcInfoModLen < 0:
+        raise ValueError(f"SetupLogging 'LogDebugCacheSize' can't be negative")
     
     
 # Add the Filter to implement stack-traces
-    if not isinstance(StackOnDebug, str):
-        raise ValueError(f"SetupLogging 'StackOnDebug' is not a string")
-    wTxt = StackOnDebug.upper()
+    if not isinstance(LogStackOnDebug, str):
+        raise ValueError(f"SetupLogging 'LogStackOnDebug' is not a string")
+    wTxt = LogStackOnDebug.upper()
     if wTxt =='ERROR':
         Sd = logging.ERROR
     elif wTxt =='STATUS':
@@ -875,8 +881,10 @@ Output format:
         Sd = logging.TRACE
     else:
         Sd = -1
-
-    logging.getLogger().addFilter(_AddStackContextFilter(StackDepth, Sd))
+    IsSyslog = False
+    if LogPath == '' and not StdErr:
+        IsSyslog = True
+    logging.getLogger().addFilter(_AddStackContextFilter(trim_amount = LogStackDepth,below_level = Sd, is_syslog = IsSyslog))
     
     if not NoDaemon:  # Ausgabe auf StdErr macht als Daemon keinen Sinn
         StdErr = False
@@ -898,47 +906,47 @@ Output format:
         LogLevel = logging.ERROR
         
     try:
-        LevelType = int(LevelType)
+        LogLevelType = int(LogLevelType)
     except:
-        raise ValueError(f"SetupLogging 'LevelType' can't be converted to an integer")
-    if LevelType == 1:
+        raise ValueError(f"SetupLogging 'LogLevelType' can't be converted to an integer")
+    if LogLevelType == 1:
         ShowLevel = '%(levelno)02d '
-    elif LevelType == 2:
+    elif LogLevelType == 2:
         ShowLevel = '%(levelname)7s '
-    elif LevelType == 3:
+    elif LogLevelType == 3:
         ShowLevel = '%(levelno)02d=%(levelname)7s '
     else:
         ShowLevel = ''
     
-    if ProcInfo:
+    if LogProcInfo:
         AddPar = ''
-        if MultiProc:
-            if MultiProcLen == 0: 
+        if LogMultiProc:
+            if LogMultiProcLen == 0: 
                 AddPar += '%(processName)s'
             else:
-                AddPar += f"%(processName){MultiProcLen}s"
-        if MultiThread:
+                AddPar += f"%(processName){LogMultiProcLen}s"
+        if LogMultiThread:
             if AddPar != '':
                 AddPar += ':'
-            if MultiThreadLen == 0:
+            if LogMultiThreadLen == 0:
                 AddPar += '%(threadName)s'
             else:
-                AddPar += f"%(threadName)-{MultiThreadLen}s"
-        if ProcInfoModLen == 0:
+                AddPar += f"%(threadName)-{LogMultiThreadLen}s"
+        if LogProcInfoModLen == 0:
             AddPar += ' %(module)s'
         else:
-            AddPar += f" %(module){ProcInfoModLen}s"
-        if ProcInfoFuncLen == 0:
+            AddPar += f" %(module){LogProcInfoModLen}s"
+        if LogProcInfoFuncLen == 0:
             AddPar += ':%(funcName)s:'
         else:
-            AddPar += f":%(funcName)-{ProcInfoFuncLen}s:"
+            AddPar += f":%(funcName)-{LogProcInfoFuncLen}s:"
         AddPar += '%(lineno)4d'
     else:
         AddPar = ''
     
-    if LogFile != '':
+    if LogPath != '':
         Format = f"%(asctime)s - {AppName} {ShowLevel}{AddPar} - %(message)s%(stack)s"
-        FileLogHand = logging.handlers.TimedRotatingFileHandler(LogFile, when = 'S',interval = LogFileInterval, backupCount = LogFileCount)
+        FileLogHand = logging.handlers.TimedRotatingFileHandler(LogPath, when = 'S',interval = LogFileInterval, backupCount = LogFileCount)
 
         FileLogHand.setLevel(LogLevel)
         Formatter = logging.Formatter(Format)
@@ -973,30 +981,30 @@ Output format:
     logging.getLogger().setLevel(1)
 
     LogServer = DummyPortLogServer()
-    if DebugPort != 0:
+    if LogDebugPort != 0:
         AddPar = ''
-        if MultiProcLen == 0: 
+        if LogMultiProcLen == 0: 
             AddPar += '%(processName)s'
         else:
-            AddPar += f"%(processName){MultiProcLen}s"
+            AddPar += f"%(processName){LogMultiProcLen}s"
         if AddPar != '':
             AddPar += ':'
-        if MultiThreadLen == 0:
+        if LogMultiThreadLen == 0:
             AddPar += '%(threadName)s'
         else:
-            AddPar += f"%(threadName)-{MultiThreadLen}s"
-        if ProcInfoModLen == 0:
+            AddPar += f"%(threadName)-{LogMultiThreadLen}s"
+        if LogProcInfoModLen == 0:
             AddPar += ' %(module)s'
         else:
-            AddPar += f" %(module){ProcInfoModLen}s"
-        if ProcInfoFuncLen == 0:
+            AddPar += f" %(module){LogProcInfoModLen}s"
+        if LogProcInfoFuncLen == 0:
             AddPar += ':%(funcName)s:'
         else:
-            AddPar += f":%(funcName)-{ProcInfoFuncLen}s:"
+            AddPar += f":%(funcName)-{LogProcInfoFuncLen}s:"
         AddPar += '%(lineno)4d'
         ShowLevel = '%(levelname)7s '
         Format = f"%(asctime)s {ShowLevel}{AddPar} - %(message)s%(stack)s"
-        LogServer = PortLogServer(host=DebugIp,port=DebugPort,queue=LogQueue,logsize=DebugCacheSize,format=Format)
+        LogServer = PortLogServer(host=LogDebugIp,port=LogDebugPort,queue=LogQueue,logsize=LogDebugCacheSize,format=Format)
         qh = PortLogQueueHandler(LogServer, LogQueue)
         qh.setLevel(1)
         logging.getLogger().addHandler(qh)
@@ -1065,10 +1073,10 @@ if __name__ == '__main__':
         MyParam['StdErr'] = True
         MyParam['NoDaemon'] = True
         MyParam['Quiet'] = False
-        MyParam['LogFile'] = ''
-        MyParam['ProcInfo'] = True
+        MyParam['LogPath'] = ''
+        MyParam['LogProcInfo'] = True
     
-    #    MyParam['LogFile'] = './TheLog.log'
+    #    MyParam['LogPath'] = './TheLog.log'
         AppName = "LogP"
     
     
@@ -1077,15 +1085,15 @@ if __name__ == '__main__':
                         StdErr = MyParam['StdErr'], 
                         NoDaemon = MyParam['NoDaemon'], 
                         Quiet = MyParam['Quiet'],
-                        LogFile = MyParam['LogFile'],
-                        ProcInfo = False,
-#                        StackOnDebug = "debug",
-#                        StackDepth=2,
-                        LevelType = 0,
-                        MultiProc = False, 
-                        MultiThread = False,
-                        ProcInfoModLen=5,
-                        DebugPort=65432
+                        LogPath = MyParam['LogPath'],
+                        LogProcInfo = False,
+#                        LogStackOnDebug = "debug",
+#                        LogStackDepth=2,
+                        LogLevelType = 0,
+                        LogMultiProc = False, 
+                        LogMultiThread = False,
+                        LogProcInfoModLen=5,
+                        LogDebugPort=65432
                         ) 
     
         LogP.error('Error')
@@ -1105,14 +1113,14 @@ if __name__ == '__main__':
                         StdErr = MyParam['StdErr'], 
                         NoDaemon = MyParam['NoDaemon'], 
                         Quiet = MyParam['Quiet'],
-                        LogFile = MyParam['LogFile'],
-                        LevelType=3,
-                        ProcInfo = True,
-                        MultiProc = False, 
-                        MultiThread = False,
-                        ProcInfoModLen=15,
-                        ProcInfoFuncLen=15,
-                        DebugPort=65432
+                        LogPath = MyParam['LogPath'],
+                        LogLevelType=3,
+                        LogProcInfo = True,
+                        LogMultiProc = False, 
+                        LogMultiThread = False,
+                        LogProcInfoModLen=15,
+                        LogProcInfoFuncLen=15,
+                        LogDebugPort=65432
                         ) 
     
         LogP.error('Error')
